@@ -441,7 +441,12 @@ dataset_collections = {
         'OPERA_L2_RTC-S1-STATIC_V1': ['C1259981910-ASF', 'C2795135174-ASF'],
         'OPERA_L2_RTC-S1_PROVISIONAL_V0': ['C1257995186-ASF'],
         'OPERA_L3_DISP-S1_V1': ['C3294057315-ASF', 'C1271830354-ASF'],
-        'OPERA_L4_TROPO-ZENITH_V1': ['C3717139408-ASF'],
+        'OPERA_L3_DISP-S1-STATIC_V1': ['C3959290248-ASF', 'C1273910948-ASF', 'C1273460752-ASFDEV'],
+        
+    },
+    'TROPO': {
+        'ASF_ECMWF_TROPO': ['C3653531162-ASF'],
+        'OPERA_L4_TROPO-ZENITH_V1': ['C3717139408-ASF', 'C1273910987-ASF', 'C1273615785-ASFDEV'],
     },
     'OPERA-S1-CALVAL': {
         'OPERA_L2_CSLC-S1_CALVAL_V1': ['C1260721945-ASF', 'C2803501758-ASF'],
@@ -1371,8 +1376,10 @@ collections_by_processing_level = {
         'C3294057315-ASF',
         'C1271830354-ASF'
     ],
-    'TROPO-ZENITH': [
-        'C3717139408-ASF',
+    'DISP-S1-STATIC': ['C3959290248-ASF', 'C1273910948-ASF', 'C1273460752-ASFDEV'],
+    'TROPO-ZENITH': ['C3717139408-ASF', 'C1273910987-ASF', 'C1273615785-ASFDEV'],
+    'ECMWF_TROPO': [
+        'C3653531162-ASF'
     ],
     'GRD_FD': [
         'C1214471197-ASF',
